@@ -19,15 +19,12 @@ padi.function.tests.simple <- function( verbose=TRUE, synopsis=TRUE, fuzz=1e-6,
   fqpscratch.db <- paste(pwd,"/",scratch.db, sep="")
   unlink(scratch.db, recursive = TRUE)
 
-  server <- Sys.info()[["nodename"]]
-  if (checkPADIserver(server))
-     stop("A server is already running. Testing stopped. Use cleanupPADIserver() or killPADIserver() to terminate it.")
 
   wait.for.server.to.terminate <- function(server)
     {# wait to ensure padi server is terminated
-     for (i in 1:30)
+     for (i in 1:60)
        {if (!checkPADIserver(server)) break
-        Sys.sleep(1)
+        Sys.sleep(2)
        }
     }
 
@@ -39,6 +36,10 @@ padi.function.tests.simple <- function( verbose=TRUE, synopsis=TRUE, fuzz=1e-6,
        }
     }
 
+  server <- Sys.info()[["nodename"]]
+  wait.for.server.to.terminate(server)
+  if (checkPADIserver(server))
+     stop("A server is already running. Testing stopped. Use cleanupPADIserver() or killPADIserver() to terminate it.")
 
 #    simple.server tests
 
